starcluster.webtools.DocrootHandler

Package starcluster :: Module webtools :: Class DocrootHandler |
[hide private]
[frames] | no frames]

# Class DocrootHandler

source code

Nested Classes | [hide private]
Inherited from `BaseHTTPServer.BaseHTTPRequestHandler`: `MessageClass`

Instance Methods | [hide private]
do_GET(self) | source code
Inherited from `BaseHandler`: `do_POST`, `do_shutdown` Inherited from `BaseHTTPServer.BaseHTTPRequestHandler`: `address_string`, `date_time_string`, `end_headers`, `handle`, `handle_one_request`, `log_date_time_string`, `log_error`, `log_message`, `log_request`, `parse_request`, `send_error`, `send_header`, `send_response`, `version_string` Inherited from `SocketServer.StreamRequestHandler`: `finish`, `setup` Inherited from `SocketServer.BaseRequestHandler`: `__init__`

Class Variables | [hide private]
Inherited from `BaseHandler`: `error_message_format` Inherited from `BaseHTTPServer.BaseHTTPRequestHandler`: `default_request_version`, `error_content_type`, `monthname`, `protocol_version`, `responses`, `server_version`, `sys_version`, `weekdayname` Inherited from `SocketServer.StreamRequestHandler`: `rbufsize`, `wbufsize`

Method Details | [hide private]

### do_GET(self) | source code
Overrides: BaseHandler.do_GET